@@ -7,11 +7,11 @@ from itertools import chain, repeat
 import urwid
 from urwid.canvas import Canvas, CanvasJoin, CompositeCanvas, SolidCanvas
 from urwid.command_map import Command
-from urwid.monitored_list import MonitoredFocusList, MonitoredList
 from urwid.util import is_mouse_press
 
 from .constants import Align, Sizing, WHSettings
 from .container import WidgetContainerListContentsMixin, WidgetContainerMixin, _ContainerElementSizingFlag
+from .monitored_list import MonitoredFocusList, MonitoredList
 from .widget import Widget, WidgetError, WidgetWarning
 
 if typing.TYPE_CHECKING:
@@ -66,40 +66,47 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
 
         # BOX-only widget
         >>> Columns((SolidFill("#"),))
-        <Columns box widget>
+        <Columns box widget with 1 item>
 
         # BOX-only widget with "get height from max"
         >>> Columns((SolidFill("#"),), box_columns=(0,))
-        <Columns box widget>
+        <Columns box widget with 1 item>
 
         # FLOW-only
         >>> Columns((Edit(),))
-        <Columns selectable flow widget>
+        <Columns selectable flow widget with 1 item>
 
         # FLOW allowed by "box_columns"
         >>> Columns((Edit(), SolidFill("#")), box_columns=(1,))
-        <Columns selectable flow widget>
+        <Columns selectable flow widget with 2 items>
 
         # FLOW/FIXED
         >>> Columns((Text("T"),))
-        <Columns fixed/flow widget>
+        <Columns fixed/flow widget with 1 item>
 
         # GIVEN BOX only -> BOX only
         >>> Columns(((5, SolidFill("#")),), box_columns=(0,))
-        <Columns box widget>
+        <Columns box widget with 1 item>
 
         # No FLOW - BOX only
         >>> Columns(((5, SolidFill("#")), SolidFill("*")), box_columns=(0, 1))
-        <Columns box widget>
+        <Columns box widget with 2 items>
 
         # FIXED only -> FIXED
         >>> Columns(((WHSettings.PACK, BigText("1", font)),))
-        <Columns fixed widget>
+        <Columns fixed widget with 1 item>
 
         # Invalid sizing combination -> use fallback settings (and produce warning)
         >>> Columns(((WHSettings.PACK, SolidFill("#")),))
-        <Columns box/flow widget>
+        <Columns box/flow widget with 1 item>
+
+        # Special case: empty columns widget sizing is impossible to calculate
+        >>> Columns(())
+        <Columns box/flow widget without contents>
         """
+        if not self.contents:
+            return frozenset((urwid.BOX, urwid.FLOW))
+
         strict_box = False
         has_flow = False
 
@@ -238,10 +245,12 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
         self._cache_column_widths: list[int] = []
         super().__init__()
         self._contents: MonitoredFocusList[
-            Widget,
-            tuple[Literal[WHSettings.PACK], None, bool]
-            | tuple[Literal[WHSettings.GIVEN], int, bool]
-            | tuple[Literal[WHSettings.WEIGHT], int | float, bool],
+            tuple[
+                Widget,
+                tuple[Literal[WHSettings.PACK], None, bool]
+                | tuple[Literal[WHSettings.GIVEN], int, bool]
+                | tuple[Literal[WHSettings.WEIGHT], int | float, bool],
+            ],
         ] = MonitoredFocusList()
         self._contents.set_modified_callback(self._contents_modified)
         self._contents.set_focus_changed_callback(lambda f: self._invalidate())
@@ -278,6 +287,13 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
         self.min_width = min_width
         self._cache_maxcol = None
 
+    def _repr_words(self) -> list[str]:
+        if len(self.contents) > 1:
+            return [*super()._repr_words(), f"with {len(self.contents)} items"]
+        if self.contents:
+            return [*super()._repr_words(), "with 1 item"]
+        return [*super()._repr_words(), "without contents"]
+
     def _contents_modified(self) -> None:
         """
         Recalculate whether this widget should be selectable whenever the
@@ -342,7 +358,7 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
                 chain(self.contents, repeat((None, (WHSettings.WEIGHT, 1, False)))),
             )
         ]
-        if focus_position < len(widgets):
+        if focus_position < len(widgets):  # pylint: disable=consider-using-max-builtin  # pylint bug
             self.focus_position = focus_position
 
     @property
@@ -383,7 +399,7 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
             (w, ({Sizing.FIXED: WHSettings.GIVEN, Sizing.FLOW: WHSettings.PACK}.get(new_t, new_t), new_n, b))
             for ((new_t, new_n), (w, (t, n, b))) in zip(column_types, self.contents)
         ]
-        if focus_position < len(column_types):
+        if focus_position < len(column_types):  # pylint: disable=consider-using-max-builtin  # pylint bug
             self.focus_position = focus_position
 
     @property
@@ -442,10 +458,12 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
     def contents(
         self,
     ) -> MonitoredFocusList[
-        Widget,
-        tuple[Literal[WHSettings.PACK], None, bool]
-        | tuple[Literal[WHSettings.GIVEN], int, bool]
-        | tuple[Literal[WHSettings.WEIGHT], int | float, bool],
+        tuple[
+            Widget,
+            tuple[Literal[WHSettings.PACK], None, bool]
+            | tuple[Literal[WHSettings.GIVEN], int, bool]
+            | tuple[Literal[WHSettings.WEIGHT], int | float, bool],
+        ],
     ]:
         """
         The contents of this Columns as a list of `(widget, options)` tuples.
@@ -922,7 +940,11 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
             tuple(w_h_args[idx] for idx in range(len(w_h_args))),
         )
 
-    def pack(self, size: tuple[()] | tuple[int] | tuple[int, int] = (), focus: bool = False) -> tuple[int, int]:
+    def pack(
+        self,
+        size: tuple[()] | tuple[int] | tuple[int, int] = (),
+        focus: bool = False,
+    ) -> tuple[int, int]:
         """Get packed sized for widget."""
         if size:
             return super().pack(size, focus)
@@ -1122,7 +1144,11 @@ class Columns(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
             rows = max(rows, w.rows((mc,), focus=focus and self.focus_position == i))
         return rows
 
-    def keypress(self, size: tuple[()] | tuple[int] | tuple[int, int], key: str) -> str | None:
+    def keypress(
+        self,
+        size: tuple[()] | tuple[int] | tuple[int, int],
+        key: str,
+    ) -> str | None:
         """
         Pass keypress to the focus column.
 
